@@ -850,7 +850,9 @@ static void cmdline_view_filer()
     char* env = getenv("PROMPT");
     if(env) {
         string_obj* str = STRING_NEW("");
-        saphire_shell3(str, env, "prompt");
+        sRFd* rfd = sRFd_new(0);
+        saphire_shell3(str, env, "prompt", rfd);
+        sRFd_delete(rfd);
 
         mmvprintw(maxy -2, 0, "%s", string_c_str(str));
 
