@@ -494,7 +494,7 @@ static void usage()
 
 static void version()
 {
-    printf("mfiler3 version %s with shell scripting system saphire version %s.", getenv("VERSION"), getenv("KITUTUKI_VERSION"));
+    printf("mfiler3 version %s with shell scripting system saphire version %s.", getenv("VERSION"), getenv("SAPHIRE_VERSION"));
     puts("This program is a traditional Japanese style 2pain file manager with a embedded shell scripting system \"saphire\". mfiler3 is developped by Daisuke Minato.");
     puts("compiled with");
 
@@ -884,7 +884,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.0.2", 1);
+    setenv("VERSION", "4.0.4", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -1079,7 +1079,9 @@ int main(int argc, char* argv[])
         else {
             saphire_set_signal();
             string_obj* ret = STRING_NEW("");
-            saphire_shell3(ret, " pidof mfiler3", "pidof mfiler3");
+            sRFd* rfd = sRFd_new(0);
+            saphire_shell3(ret, " pidof mfiler3", "pidof mfiler3", rfd);
+            sRFd_delete(rfd);
 
             char* p = string_c_str(ret);
             int pid = 0;
@@ -1342,7 +1344,9 @@ int main(int argc, char* argv[])
             else if(buf[0] == 'e') {
                 saphire_set_signal();
                 string_obj* str = STRING_NEW("");
+                sRFd* rfd = sRFd_new(0);
                 saphire_shell3(str, buf + 1, "mfiler3 -E");
+                sRFd_delete(rfd);
 
                 int pipe = open(pipe_name, O_WRONLY);
                 write(pipe, string_c_str(str), string_size(str) +1);
@@ -1359,7 +1363,9 @@ int main(int argc, char* argv[])
 
     /// ごみソケットとパイプの掃除 ///
     string_obj* ret = STRING_NEW("");
-    saphire_shell3(ret, " pidof mfiler3", "clean mfiler3 sockets");
+    sRFd* rfd = sRFd_new(0);
+    saphire_shell3(ret, " pidof mfiler3", "clean mfiler3 sockets", rfd);
+    sRFd_delete(rfd);
 
     DIR* dir = opendir(gTempDir);
     if(dir == NULL) {
